/**
 * \file core/slurm_process/slurmprocess.h
 * \date 21/09/2023
 * \author Olivier Langella
 * \brief handles execution of processes through slurm
 * workload manager
 */

/*******************************************************************************
 * Copyright (c) 2023 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of i2MassChroQ.
 *
 *     i2MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     i2MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with i2MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#pragma once
#include "../../utils/workmonitor.h"
#include "../../gui/mainwindow.h"
#include <QTemporaryDir>
#include <QProcess>
/**
 * @todo write docs
 */
class SlurmProcess : public QProcess
{
  Q_OBJECT
  public:
  /**
   * Default constructor
   */
  SlurmProcess(MainWindow *p_main_window,
               WorkMonitorInterface *p_monitor,
               QString app_run);


  /**
   * Destructor
   */
  ~SlurmProcess();

  protected:
  void prepareTemporaryDirectory();

  void startSlurmProcess(const QString &batch_file_name);

  protected:
  QTemporaryDir *mp_tmpDir = nullptr;

  private:
  MainWindow *mp_mainWindow;
  WorkMonitorInterface *mp_monitor;
  QString m_runName;
  QString m_slurmSbatchCommand;

  int m_maxLaunchTime = (60000 * 60 * 24); // 1 day
};
